@@ -163,6 +163,7 @@ reverse_geo_lite_single <- function(lat_cap,
 
   json <- tempfile(fileext = ".json")
 
+  # nocov start
   res <- tryCatch(
     download.file(url, json, mode = "wb", quiet = isFALSE(verbose)),
     warning = function(e) {
@@ -174,16 +175,20 @@ reverse_geo_lite_single <- function(lat_cap,
   )
 
   if (is.null(res)) {
-    message(url, " not reachable. Returning NULL.")
-    return(NULL)
+    message(url, " not reachable.")
+    result_out <- tibble::tibble(ad = NA)
+    names(result_out) <- address
+    return(result_out)
   }
 
+  # nocov end
+
   result_init <- jsonlite::fromJSON(json, flatten = TRUE)
 
   if ("error" %in% names(result_init)) {
-    warning("No results for query lon=",
-      long_cap, ", lat=", lat_cap,
-      call. = FALSE
+    message(
+      "No results for query lon=",
+      long_cap, ", lat=", lat_cap
     )
     result_out <- tibble::tibble(ad = NA)
     names(result_out) <- address
