@@ -1,9 +1,15 @@
 test_that("Returning empty query", {
-  skip_if_offline()
-  expect_warning(geo_amenity(
+  obj <- expect_message(geo_amenity(
     bbox = c(-1.1446, 41.5022, -0.4854, 41.8795),
     amenity = "xbzbzbzoa aiaia"
   ))
+
+  expect_true(ncol(obj) == 3)
+  expect_true(nrow(obj) == 1)
+
+  expect_true(obj$query == "xbzbzbzoa aiaia")
+  expect_true(is.na(obj$lat))
+  expect_true(is.na(obj$lon))
 })
 
 test_that("Data format", {
