@@ -1,9 +1,12 @@
 test_that("Returning empty query", {
-  skip_if_offline()
-  expect_warning(geo_amenity_sf(
+  obj <- expect_message(geo_amenity_sf(
     bbox = c(-1.1446, 41.5022, -0.4854, 41.8795),
     amenity = "xbzbzbzoa aiaia"
   ))
+
+  expect_true(nrow(obj) == 1)
+  expect_true(ncol(obj) == 1)
+  expect_true(obj$query == "xbzbzbzoa aiaia")
 })
 
 test_that("Data format", {
